Attribute VB_Name = "MToken"
'
' MiniBrowser
' Written by Paul Kershaw 2002-2004
' Copyright (C) 2002, 2004
'
' This source file is part of MiniBrowser.
'
' MiniBrowser is free software; you can redistribute it and/or modify
' it under the terms of the GNU General Public License as published by
' the Free Software Foundation; either version 2 of the License, or
' (at your option) any later version.
'
' Foobar is distributed in the hope that it will be useful,
' but WITHOUT ANY WARRANTY; without even the implied warranty of
' MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
' GNU General Public License for more details.
'
' You should have received a copy of the GNU General Public License
' along with Foobar; if not, write to the Free Software
' Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
'

Const ThisModule = "MToken"

'Option Explicit

''taken from an ancient QBasic program called 'REMLINE.BAS'
''modified by paul kershaw for vb6

'
' GetToken$:
'  Extracts tokens from a string. A token is a word that is surrounded
'  by separators, such as spaces or commas. Tokens are extracted and
'  analyzed when parsing sentences or commands. To use the GetToken$
'  function, pass the string to be parsed on the first call, then pass
'  a null string on subsequent calls until the function returns a null
'  to indicate that the entire string has been parsed.
' Input:
'  Search$ = string to search
'  Delim$  = String of separators
' Output:
'  GetToken$ = next token
'
Static Function GetToken$(Search$, Delim$)
   ' Note that SaveStr$ and BegPos must be static from call to call
   ' (other variables are only static for efficiency).
   ' If first call, make a copy of the string
   If Len(Search$) Then
      BegPos = 1
      SaveStr$ = Search$
   End If
  
   ' Find the start of the next token
   NewPos = StrSpn(Mid$(SaveStr$, BegPos, Len(SaveStr$)), Delim$)
   If NewPos Then
      ' Set position to start of token
      BegPos = NewPos + BegPos - 1
   Else
      ' If no new token, quit and return null
      GetToken$ = vbNullString
      Exit Function
   End If

   ' Find end of token
   NewPos = StrBrk(Mid$(SaveStr$, BegPos, Len(SaveStr$)), Delim$)
   If NewPos Then
      ' Set position to end of token
      NewPos = BegPos + NewPos - 1
   Else
      ' If no end of token, return set to end a value
      NewPos = Len(SaveStr$) + 1
   End If
   ' Cut token out of search string
   GetToken$ = Mid$(SaveStr$, BegPos, NewPos - BegPos)
   ' Set new starting position
   BegPos = NewPos
End Function

'
' StrBrk:
'  Searches InString$ to find the first character from among those in
'  Separator$. Returns the index of that character. This function can
'  be used to find the end of a token.
' Input:
'  InString$ = string to search
'  Separator$ = characters to search for
' Output:
'  StrBrk = index to first match in InString$ or 0 if none match
'
Static Function StrBrk(InString$, Separator$)
   Dim Ln As Integer
   
   Ln = Len(InString$)
   BegPos = 1
   ' Look for end of token (first character that is a delimiter).
   Do While InStr(Separator$, Mid$(InString$, BegPos, 1)) = 0
      If BegPos > Ln Then
         StrBrk = 0
         Exit Function
      Else
         BegPos = BegPos + 1
      End If
   Loop
   StrBrk = BegPos
End Function

'
' StrSpn:
'  Searches InString$ to find the first character that is not one of
'  those in Separator$. Returns the index of that character. This
'  function can be used to find the start of a token.
' Input:
'  InString$ = string to search
'  Separator$ = characters to search for
' Output:
'  StrSpn = index to first nonmatch in InString$ or 0 if all match
'
Static Function StrSpn%(InString$, Separator$)
   Ln = Len(InString$)
   BegPos = 1
   ' Look for start of a token (character that isn't a delimiter).
   Do While InStr(Separator$, Mid$(InString$, BegPos, 1))
      If BegPos > Ln Then
         StrSpn = 0
         Exit Function
      Else
         BegPos = BegPos + 1
      End If
   Loop
   StrSpn = BegPos
End Function

